# This file was auto-generated by Fern from our API Definition.

import typing

WebhookUsageType = typing.Union[
    typing.Literal["ConvAI Agent Settings", "ConvAI Settings", "Voice Library Removal Notices", "Speech to Text"],
    typing.Any,
]
