# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .conversation_history_multivoice_message_part_model import ConversationHistoryMultivoiceMessagePartModel


class ConversationHistoryMultivoiceMessageModel(UncheckedBaseModel):
    """
    Represents a message from a multi-voice agent.
    """

    parts: typing.List[ConversationHistoryMultivoiceMessagePartModel]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
