# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        DocumentsGetResponse,
        DocumentsGetResponse_File,
        DocumentsGetResponse_Folder,
        DocumentsGetResponse_Text,
        DocumentsGetResponse_Url,
        DocumentsUpdateResponse,
        DocumentsUpdateResponse_File,
        DocumentsUpdateResponse_Folder,
        DocumentsUpdateResponse_Text,
        DocumentsUpdateResponse_Url,
    )
    from . import chunk, summaries
    from .summaries import (
        SummariesGetResponseValue,
        SummariesGetResponseValue_Failure,
        SummariesGetResponseValue_Success,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "DocumentsGetResponse": ".types",
    "DocumentsGetResponse_File": ".types",
    "DocumentsGetResponse_Folder": ".types",
    "DocumentsGetResponse_Text": ".types",
    "DocumentsGetResponse_Url": ".types",
    "DocumentsUpdateResponse": ".types",
    "DocumentsUpdateResponse_File": ".types",
    "DocumentsUpdateResponse_Folder": ".types",
    "DocumentsUpdateResponse_Text": ".types",
    "DocumentsUpdateResponse_Url": ".types",
    "SummariesGetResponseValue": ".summaries",
    "SummariesGetResponseValue_Failure": ".summaries",
    "SummariesGetResponseValue_Success": ".summaries",
    "chunk": ".chunk",
    "summaries": ".summaries",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "DocumentsGetResponse",
    "DocumentsGetResponse_File",
    "DocumentsGetResponse_Folder",
    "DocumentsGetResponse_Text",
    "DocumentsGetResponse_Url",
    "DocumentsUpdateResponse",
    "DocumentsUpdateResponse_File",
    "DocumentsUpdateResponse_Folder",
    "DocumentsUpdateResponse_Text",
    "DocumentsUpdateResponse_Url",
    "SummariesGetResponseValue",
    "SummariesGetResponseValue_Failure",
    "SummariesGetResponseValue_Success",
    "chunk",
    "summaries",
]
