# This file was auto-generated by Fern from our API Definition.

import typing

ConversationInitiationSource = typing.Union[
    typing.Literal[
        "unknown",
        "android_sdk",
        "node_js_sdk",
        "react_native_sdk",
        "react_sdk",
        "js_sdk",
        "python_sdk",
        "widget",
        "sip_trunk",
        "twilio",
        "genesys",
        "swift_sdk",
        "whatsapp",
        "flutter_sdk",
        "zendesk_integration",
    ],
    typing.Any,
]
