# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .unit_test_summary_response_model import UnitTestSummaryResponseModel


class GetTestsSummariesByIdsResponseModel(UncheckedBaseModel):
    tests: typing.Dict[str, UnitTestSummaryResponseModel] = pydantic.Field()
    """
    Dictionary mapping test IDs to their summary information
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
