# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .literal_override import LiteralOverride

if typing.TYPE_CHECKING:
    from .object_override_output import ObjectOverrideOutput
ObjectOverrideOutputPropertiesValue = typing.Union[LiteralOverride, "ObjectOverrideOutput"]
