# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ObjectOverrideInput(UncheckedBaseModel):
    description: typing.Optional[str] = None
    properties: typing.Optional[typing.Dict[str, typing.Optional["ObjectOverrideInputPropertiesValue"]]] = None
    required: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .object_override_input_properties_value import ObjectOverrideInputPropertiesValue  # noqa: E402, I001
