# This file was auto-generated by Fern from our API Definition.

import typing

AddPronunciationDictionaryResponseModelPermissionOnResource = typing.Union[
    typing.Literal["admin", "editor", "commenter", "viewer"], typing.Any
]
