# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .canvas_placement import CanvasPlacement
from .project_video_thumbnail_sheet_response_model import ProjectVideoThumbnailSheetResponseModel


class ProjectVideoResponseModel(UncheckedBaseModel):
    video_id: str
    filename: str
    signed_url: typing.Optional[str] = None
    signed_preview_url: typing.Optional[str] = None
    offset_ms: int
    duration_ms: int
    volume_gain_db: float
    muted: bool
    width: int
    height: int
    codec: str
    order: str
    preview_job_progress: float
    created_at_ms: int
    updated_at_ms: int
    error: typing.Optional[str] = None
    thumbnail_interval_seconds: float
    thumbnail_size: typing.List[int]
    thumbnail_sheets: typing.List[ProjectVideoThumbnailSheetResponseModel]
    start_time_ms: int
    end_time_ms: int
    asset_preview_signed_url: typing.Optional[str] = None
    source_video_id: typing.Optional[str] = None
    source_asset_id: typing.Optional[str] = None
    pending_block_ids: typing.List[str]
    import_speech_progress: typing.Optional[float] = None
    speech_imported: typing.Optional[bool] = None
    audio_track_ready: typing.Optional[bool] = None
    current_snapshot_id: typing.Optional[str] = None
    canvas_placement: typing.Optional[CanvasPlacement] = None
    track_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
