# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata


class AstGreaterThanOperatorNodeOutputRight_AndOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["and_operator"] = "and_operator"
    children: typing.List["AstAndOperatorNodeOutputChildrenItem"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_BooleanLiteral(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["boolean_literal"] = "boolean_literal"
    value: bool

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_DynamicVariable(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["dynamic_variable"] = "dynamic_variable"
    name: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_EqOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["eq_operator"] = "eq_operator"
    left: "AstEqualsOperatorNodeOutputLeft"
    right: "AstEqualsOperatorNodeOutputRight"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_GtOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["gt_operator"] = "gt_operator"
    left: "AstGreaterThanOperatorNodeOutputLeft"
    right: "AstGreaterThanOperatorNodeOutputRight"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_GteOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["gte_operator"] = "gte_operator"
    left: "AstGreaterThanOrEqualsOperatorNodeOutputLeft"
    right: "AstGreaterThanOrEqualsOperatorNodeOutputRight"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_Llm(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["llm"] = "llm"
    prompt: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_LtOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["lt_operator"] = "lt_operator"
    left: "AstLessThanOperatorNodeOutputLeft"
    right: "AstLessThanOperatorNodeOutputRight"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_LteOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["lte_operator"] = "lte_operator"
    left: "AstLessThanOrEqualsOperatorNodeOutputLeft"
    right: "AstLessThanOrEqualsOperatorNodeOutputRight"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_NeqOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["neq_operator"] = "neq_operator"
    left: "AstNotEqualsOperatorNodeOutputLeft"
    right: "AstNotEqualsOperatorNodeOutputRight"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_NumberLiteral(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["number_literal"] = "number_literal"
    value: float

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_OrOperator(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["or_operator"] = "or_operator"
    children: typing.List["AstOrOperatorNodeOutputChildrenItem"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class AstGreaterThanOperatorNodeOutputRight_StringLiteral(UncheckedBaseModel):
    """
    Right operand of the binary operator.
    """

    type: typing.Literal["string_literal"] = "string_literal"
    value: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


AstGreaterThanOperatorNodeOutputRight = typing_extensions.Annotated[
    typing.Union[
        AstGreaterThanOperatorNodeOutputRight_AndOperator,
        AstGreaterThanOperatorNodeOutputRight_BooleanLiteral,
        AstGreaterThanOperatorNodeOutputRight_DynamicVariable,
        AstGreaterThanOperatorNodeOutputRight_EqOperator,
        AstGreaterThanOperatorNodeOutputRight_GtOperator,
        AstGreaterThanOperatorNodeOutputRight_GteOperator,
        AstGreaterThanOperatorNodeOutputRight_Llm,
        AstGreaterThanOperatorNodeOutputRight_LtOperator,
        AstGreaterThanOperatorNodeOutputRight_LteOperator,
        AstGreaterThanOperatorNodeOutputRight_NeqOperator,
        AstGreaterThanOperatorNodeOutputRight_NumberLiteral,
        AstGreaterThanOperatorNodeOutputRight_OrOperator,
        AstGreaterThanOperatorNodeOutputRight_StringLiteral,
    ],
    UnionMetadata(discriminant="type"),
]
from .ast_and_operator_node_output_children_item import AstAndOperatorNodeOutputChildrenItem  # noqa: E402, I001
from .ast_equals_operator_node_output_left import AstEqualsOperatorNodeOutputLeft  # noqa: E402, I001
from .ast_equals_operator_node_output_right import AstEqualsOperatorNodeOutputRight  # noqa: E402, I001
from .ast_greater_than_operator_node_output_left import AstGreaterThanOperatorNodeOutputLeft  # noqa: E402, I001
from .ast_greater_than_or_equals_operator_node_output_left import AstGreaterThanOrEqualsOperatorNodeOutputLeft  # noqa: E402, I001
from .ast_greater_than_or_equals_operator_node_output_right import AstGreaterThanOrEqualsOperatorNodeOutputRight  # noqa: E402, I001
from .ast_less_than_operator_node_output_left import AstLessThanOperatorNodeOutputLeft  # noqa: E402, I001
from .ast_less_than_operator_node_output_right import AstLessThanOperatorNodeOutputRight  # noqa: E402, I001
from .ast_less_than_or_equals_operator_node_output_left import AstLessThanOrEqualsOperatorNodeOutputLeft  # noqa: E402, I001
from .ast_less_than_or_equals_operator_node_output_right import AstLessThanOrEqualsOperatorNodeOutputRight  # noqa: E402, I001
from .ast_not_equals_operator_node_output_left import AstNotEqualsOperatorNodeOutputLeft  # noqa: E402, I001
from .ast_not_equals_operator_node_output_right import AstNotEqualsOperatorNodeOutputRight  # noqa: E402, I001
from .ast_or_operator_node_output_children_item import AstOrOperatorNodeOutputChildrenItem  # noqa: E402, I001

update_forward_refs(AstGreaterThanOperatorNodeOutputRight_AndOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_EqOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_GtOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_GteOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_LtOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_LteOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_NeqOperator)
update_forward_refs(AstGreaterThanOperatorNodeOutputRight_OrOperator)
