# This file was auto-generated by Fern from our API Definition.

import typing

BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender = typing.Union[
    typing.Literal["female", "male"], typing.Any
]
