# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .feature_status_common_model import FeatureStatusCommonModel


class WorkflowFeaturesUsageCommonModel(UncheckedBaseModel):
    enabled: typing.Optional[bool] = None
    tool_node: typing.Optional[FeatureStatusCommonModel] = None
    standalone_agent_node: typing.Optional[FeatureStatusCommonModel] = None
    phone_number_node: typing.Optional[FeatureStatusCommonModel] = None
    end_node: typing.Optional[FeatureStatusCommonModel] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
